/*
 * drivers/media/video/mt9p031_regs.h
 *
 * Copyright (C) 2008 Texas Instruments Inc
 * Author: Vaibhav Hiremath <hvaibhav@ti.com>
 *
 * Contributors:
 *     Sivaraj R <sivaraj@ti.com>
 *     Brijesh R Jadav <brijesh.j@ti.com>
 *     Hardik Shah <hardik.shah@ti.com>
 *     Manjunath Hadli <mrh@ti.com>
 *     Karicheri Muralidharan <m-karicheri2@ti.com>
 *
 * This package is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _MT9P031_REGS_H
#define _MT9P031_REGS_H

/* Definitions to access the various sensor registers */
#define MT9P031_CHIP_VERSION			(0x00)
#define MT9P031_ROW_START			(0x01)
#define MT9P031_COL_START			(0x02)
#define MT9P031_HEIGHT				(0x03)
#define MT9P031_WIDTH				(0x04)
#define MT9P031_HBLANK				(0x05)
#define MT9P031_VBLANK				(0x06)
#define MT9P031_OUTPUT_CTRL			(0x07)
#define MT9P031_SHUTTER_WIDTH_UPPER		(0x08)
#define MT9P031_SHUTTER_WIDTH			(0x09)
#define MT9P031_PIXEL_CLK_CTRL			(0x0A)
#define MT9P031_RESTART				(0x0B)
#define MT9P031_SHUTTER_DELAY			(0x0C)
#define MT9P031_RESET				(0x0D)
#define MT9P031_PLL_CTRL			(0x10)
#define MT9P031_PLL_CFG1			(0x11)
#define MT9P031_PLL_CFG2			(0x12)
#define MT9P031_READ_MODE1			(0x1E)
#define MT9P031_READ_MODE2			(0x20)
#define MT9P031_ROW_ADDR_MODE			(0x22)
#define MT9P031_COL_ADDR_MODE			(0x23)
#define MT9P031_GREEN1_GAIN			(0x2B)
#define MT9P031_BLUE_GAIN			(0x2C)
#define MT9P031_RED_GAIN			(0x2D)
#define MT9P031_GREEN2_GAIN			(0x2E)
#define MT9P031_GLOBAL_GAIN			(0x35)
#define MT9P031_TST_PAT_CTRL			(0xA0)
#define MT9P031_TST_PAT_GR			(0xA1)
#define MT9P031_TST_PAT_R			(0xA2)
#define MT9P031_TST_PAT_B			(0xA3)
#define MT9P031_TST_PAT_BAR_WIDTH		(0xA4)
#define MT9P031_CHIP_VERSION_END		(0xFF)

/* Macros for default register values */
#define MT9P031_ROW_START_DEFAULT		(0x0036)
#define MT9P031_COLUMN_START_DEFAULT		(0x0010)
#define MT9P031_ROW_SIZE_DEFAULT		(0x0797)
#define MT9P031_COLUMN_SIZE_DEFAULT		(0x0A1F)
#define MT9P031_HOR_BLANK_DEFAULT		(0x0000)
#define MT9P031_VER_BLANK_DEFAULT		(0x0019)
#define MT9P031_OUTPUT_CTRL_DEFAULT		(0x1F82)
#define MT9P031_SHUTTER_WIDTH_UPPER_DEFAULT	(0x0000)
#define MT9P031_SHUTTER_WIDTH_DEFAULT		(0x0797)
#define MT9P031_PIXEL_CLK_CTRL_DEFAULT		(0x0000)
#define MT9P031_FRAME_RESTART_DEFAULT		(0x0000)
#define MT9P031_SHUTTER_DELAY_DEFAULT		(0x0000)
#define MT9P031_PLL_CTRL_DEFAULT		(0x0050)
#define MT9P031_PLL_CTRL_POWER_UP		(0x0051)
#define MT9P031_PLL_CTRL_USE_PLL_CLK		(0x0053)
#define MT9P031_PLL_CFG1_96MHZ			(0x1001)
#define MT9P031_PLL_CFG1_DEFAULT		(0x6404)
#define MT9P031_PLL_CFG2_DEFAULT		(0x0000)
#define MT9P031_PLL_CFG2_96MHZ			(0x0003)
#define MT9P031_READ_MODE1_DEFAULT		(0x4006)
#define MT9P031_READ_MODE2_DEFAULT		(0x0040)
#define MT9P031_ROW_ADDR_MODE_DEFAULT		(0x0000)
#define MT9P031_COL_ADDR_MODE_DEFAULT		(0x0000)
#define MT9P031_GREEN1_GAIN_DEFAULT		(0x0008)
#define MT9P031_BLUE_GAIN_DEFAULT		(0x0008)
#define MT9P031_RED_GAIN_DEFAULT		(0x0008)
#define MT9P031_GREEN2_GAIN_DEFAULT		(0x0008)
#define MT9P031_GLOBAL_GAIN_DEFAULT		(0x0008)
#define MT9P031_TST_PAT_CTRL_DEFAULT		(0x0000)
#define MT9P031_TST_PAT_GR_DEFAULT		(0x0000)
#define MT9P031_TST_PAT_R_DEFAULT		(0x0000)
#define MT9P031_TST_PAT_B_DEFAULT		(0x0000)
#define MT9P031_TST_PAT_BAR_WIDTH_DEFAULT	(0x0000)

#define	MT9P031_OUTPUT_CTRL_MASK 		(0x1F8E)
#define MT9P031_PLL_USE_EXTERNAL		(0x51)
#define MT9P031_PLL_ENABLE			(0x53)
#define	MT9P031_HALT_MODE			(0x1F83)

/* Define Shift and Mask for PLL register*/

#define	MT9P031_PLL_M_SHIFT	(8)
#define	MT9P031_PLL_N_MASK	(0x003F)
#define	MT9P031_PLL_P1_MASK	(0x001F)

/* Define Shift and Mask for gain register*/
#define MT9P031_ANALOG_GAIN_SHIFT		0
#define MT9P031_ANALOG_MULT_SHIFT		6
#define MT9P031_DIGITAL_GAIN_SHIFT		8

#define MT9P031_ANALOG_GAIN_MASK		0x3F
#define MT9P031_ANALOG_MULT_MASK		0x1
#define MT9P031_DIGITAL_GAIN_MASK		0x3F

#define MT9P031_SHUTTER_WIDTH_LOWER_MASK	0xFFFF
#define MT9P031_SHUTTER_WIDTH_UPPER_SHIFT	16
#define MT9P031_ONE_BIT_MASK			(0x1)
#define MT9P031_TST_PAT_VAL_MASK		(0xFFF)
#define MT9P031_TST_PAT_BAR_WIDTH_MASK		(0xFFF)
#define MT9P031_N0_CHANGE_MODE			(0x0003)
#define MT9P031_NORMAL_OPERATION_MODE		(0x0002)
#define MT9P031_RESET_ENABLE			(0x0001)
#define MT9P031_RESET_DISABLE			(0x0000)
#define MT9P031_MIRROR_ROW_SHIFT		(15)
#define MT9P031_MIRROR_COL_SHIFT		(14)
#define MT9P031_SHOW_DK_COLS_SHIFT		(12)
#define MT9P031_SHOW_DK_ROWS_SHIFT		(11)

/* Pixel clock control register values */
#define MT9P031_PIX_CLK_RISING			(0x8000)
#define MT9P031_PIX_CLK_FALLING			(0x0000)


/* Tokens for register write */
#define TOK_WRITE                       (0)     /* token for write operation */
#define TOK_TERM                        (1)     /* terminating token */
#define TOK_DELAY                       (2)     /* delay token for reg list */
#define TOK_SKIP                        (3)     /* token to skip a register */

#define MT9P031_IMAGE_STD_VGA			(0x0)
#define MT9P031_IMAGE_STD_XGA			(0x01)
#define MT9P031_IMAGE_STD_720P			(0x02)
#define MT9P031_IMAGE_STD_1080P			(0x03)
#define MT9P031_IMAGE_STD_2592X1944		(0x04)
#define MT9P031_IMAGE_STD_INVALID		(0xFF)

/**
 * struct mt9p031_reg - Structure for register initialization values
 * @token - Token: TOK_WRITE, TOK_TERM etc..
 * @reg - Register offset
 * @val - Register Value for TOK_WRITE or delay in ms for TOK_DELAY
 */
struct mt9p031_reg {
	unsigned short token;
	unsigned short reg;
	unsigned short val;
};

/**
 * struct mt9p031_init_seq - Structure for power up sequence.
 * @ no_regs - Number of registers to write for power up sequence.
 * @ init_reg_seq - Array of registers and respective value to write.
 */
struct mt9p031_init_seq {
	unsigned int no_regs;
	const struct mt9p031_reg *init_reg_seq;
};

#define MT9P031_CHIP_VERSION_VALUE		(0x1801)

#endif				/* ifndef _MT9P031_REGS_H */
